---
name: 🐛 Bug Report
about: Report a bug
---

<!--To help us understand and resolve your issue, please fill out the form to the best of your ability.-->
<!--You can feel free to delete the sections that do not apply.-->

### Bug report

**Bug summary**

<!--A short 1-2 sentences that succinctly describes the bug-->

**Code for reproduction**

<!--A minimum code snippet required to reproduce the bug.
Please make sure to minimize the number of dependencies required.

```python
# Paste your code here
#
#
```

**Actual outcome**

<!--The output produced by the above code, which may be a screenshot, console output, etc.-->

**Expected outcome**

<!--A description of the expected outcome from the code snippet-->

**Version Info**
<!--Please specify your platform and versions of the relevant libraries you are using:-->
  * Operating system:
  * Python version:
  * Package version:
  * Other libraries:
